#!/bin/sh
# $Id: dar-backup.sh,v 1.5 2011/05/10 09:52:11 root Exp $
# Needs curl, dar and mutt
#
# Backup Job

KEEP_BACKUPS=4
LOGFILE="/var/log/darbackup.log"
DATE=`date -I`

if [ -e /etc/dar-backup/dar-backup.conf ]; then
 . /etc/dar-backup/dar-backup.conf
 if [ -e /etc/dar-backup/dar-exclude.conf ]; then
  . /etc/dar-backup/dar-exclude.conf
 fi
elif [ -e /etc/backup-full.conf ]; then
 . /etc/backup-full.conf
else
 echo "No config file found for $0" >2
 exit 1
fi

if [ "x$CURLFS"!="x" ]; then
  if ! ( df -P | awk '$1 ~ /curlftpfs/ { print $6 }' | grep $CURLFS > /dev/null ); then
    curlftpfs -o user=$FTPUSER:$FTPPASS $FTPSERVER $CURLFS || exit $?
  fi
fi

(
# Make sure FTPSERVER has a trailing / and starts with ftp://
if echo $FTPSERVER | egrep -q -v '^ftp://' > /dev/null ; then
  FTPSERVER="ftp://$FTPSERVER"
fi
if echo $FTPSERVER | egrep -q -v '/$' > /dev/null ; then
  FTPSERVER="$FTPSERVER/"
fi
# Make sure BACKUPDIR has no leading or trailing /
BACKUPDIR=`echo $BACKUPDIR | sed 's/^\///; s/\/$//'`

cd /$BACKUPDIR || exit 1
mkdir -p $DATE
cd /$BACKUPDIR/$DATE || exit 1

find . -maxdepth 1 -name "$HOSTID-*" -mtime +1 | xargs -r rm
SLICE="-s 100M"
[ "$1" = "--no-slice" ] && SLICE=""
dar -c /$BACKUPDIR/$DATE/$HOSTID-$DATE \
    -R / $SLICE \
    $DAREXCLUDE \
    -y \
    -G /$BACKUPDIR/$DATE/$HOSTID-$DATE-catalog \
    -D \
    -aa \
    -Q

status=$?
echo "dar-exit-status: $status"
echo $status >/$BACKUPDIR/$DATE/status
echo -e "`date`\t$status" >>$LOGFILE

sync


cd /$BACKUPDIR || exit 1
# s. /usr/lib/nagios/plugins/lihas/check_darbackup.sh
$DAR_STATUS_PATTERN_OK='0|11'
lastgoodstatedir=`egrep -l "$DAR_STATUS_PATTERN_OK"  [2-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]/status 2>/dev/null | tail -1 | cut -d'/' -f1`

ls -d [2-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9] |
head -n -$KEEP_BACKUPS | 
while read d; do
  [ "$d" = "$lastgoodstatedir" ] && continue
  rm -rf "$d"
done
cp /etc/motd .

) 2>&1 | mutt -s "Backup $HOSTID $DATE" $BACKUPMAIL

